@@ -1,3 +1,6 @@
+# TODO: Implementation of this mixin is wrong for ChoiceField (single choice variant):
+#  The ChoiceField will return data in an array even for (Single)ChoiceField. Select2 handles this, maybe even requires
+#  this, but some other component might not
 import ast
 
 from rest_framework.fields import ChoiceField, MultipleChoiceField
@@ -64,7 +67,7 @@ class AllowTagsMixin(object):
                 self.fail('invalid_choice', input=data)
 
     def to_representation(self, value, row_data=None):
-        if isinstance(self, ChoiceField) and self.allow_tags:
+        if isinstance(self, ChoiceField) and self.allow_tags and value:
             return DenormalisedArray(value, self)
 
         return super().to_representation(value, row_data)
